@@ -16,10 +16,10 @@ function(res, file = "", Vselec = "cos2", Vcoef = 1, nmax = 10, figure.title = "
       return(warning("the parameter 'res' has to be an object of class 'PCA', 'CA', 'CaGalt', 'MCA', 'MFA', 'DMFA', 'FAMD', 'GPA' or 'HCPC'"))
     }
     else if(analyse == 'CA') {
-      writeRmd(gettext("The detection of outliers does not apply to CA results"), file = file, end = ".\n\n")
+      writeRmd(gettext("The detection of outliers does not apply to CA results",domain="R-FactoInvestigate"), file = file, end = ".\n\n")
       return(list(new.res = res, res.out = res, memory = NULL))
     } else if(analyse == "CaGalt") {
-      writeRmd(gettext("The detection of outliers does not apply to CaGalt results"), file = file, end = ".\n\n")
+      writeRmd(gettext("The detection of outliers does not apply to CaGalt results",domain="R-FactoInvestigate"), file = file, end = ".\n\n")
       return(list(new.res = res, res.out = res, memory = NULL))
     }
     param = getParam(res)
@@ -90,16 +90,16 @@ res.temp = res
   
     if(!is.null(extrem)) {
       if(length(extrem) == 1){
-        writeRmd(gettext("The analysis of the graphs leads to detect an outlier that strongly influences the results"),
-                 gettext("First we will describe this outlier and then we will suppress it from the analysis"), file = file, sep = ". ", end = ".\n")
-        writeRmd(gettext("Looking at the graph, we can note that a particular individual strongly contributes to the construction of the plane"), ". ",
-                 gettext("Its contribution to the construction of the plane equals"), " **", round(weighted.mean(memory$ind$contrib[extrem, 1:2], memory$eig[1:2,1]), 1), 
+        writeRmd(gettext("The analysis of the graphs leads to detect an outlier that strongly influences the results",,domain="R-FactoInvestigate"),
+                 gettext("First we will describe this outlier and then we will suppress it from the analysis",domain="R-FactoInvestigate"), file = file, sep = ". ", end = ".\n")
+        writeRmd(gettext("Looking at the graph, we can note that a particular individual strongly contributes to the construction of the plane",domain="R-FactoInvestigate"), ". ",
+                 gettext("Its contribution to the construction of the plane equals",domain="R-FactoInvestigate"), " **", round(weighted.mean(memory$ind$contrib[extrem, 1:2], memory$eig[1:2,1]), 1), 
                  end = "%**.\n", file = file, sep = "")
       } else {
-        writeRmd(gettext("The analysis of the graphs leads to detect outliers that strongly influence the results"),
-                 gettext("First we will describe these outliers and then we will suppress them from the analysis"), file = file, sep = ". ", end = ".\n")
-        writeRmd(gettext("Looking at the graph, we can note that"), " ", length(extrem), " ", gettext("particular individuals strongly contribute to the construction of the plane"), ". ",
-                 gettext("The cumulative contribution of these individuals to the construction of the plane equals"), " **", round(weighted.mean(apply(memory$ind$contrib[extrem, 1:2], 2, sum), memory$eig[1:2,1]), 1), 
+        writeRmd(gettext("The analysis of the graphs leads to detect outliers that strongly influence the results",domain="R-FactoInvestigate"),
+                 gettext("First we will describe these outliers and then we will suppress them from the analysis",domain="R-FactoInvestigate"), file = file, sep = ". ", end = ".\n")
+        writeRmd(gettext("Looking at the graph, we can note that",domain="R-FactoInvestigate"), " ", length(extrem), " ", gettext("particular individuals strongly contribute to the construction of the plane",domain="R-FactoInvestigate"), ". ",
+                 gettext("The cumulative contribution of these individuals to the construction of the plane equals",domain="R-FactoInvestigate"), " **", round(weighted.mean(apply(memory$ind$contrib[extrem, 1:2], 2, sum), memory$eig[1:2,1]), 1), 
                  end = "%**.\n", file = file, sep = "")
       }
       
@@ -125,19 +125,19 @@ res.temp = res
                res = PCA(param$data, quanti.sup = param$quanti.sup, quali.sup = param$quali.sup, ind.sup = ind.sup, graph = FALSE, scale.unit = param$scale, row.w = row.w, col.w = param$col.w, ncp = param$ncp.mod)
                
                if(graph) {
-                 plot.PCA(memory, choix = 'ind', invisible = c('var', 'quali'), select = ind.names[extrem], title = gettext("Individuals factor map (PCA) before correction"), cex = cex)
-                 plot.PCA(res, choix = 'ind', invisible = c('var', 'quali'), select = drawn, title = gettext("Individuals factor map (PCA) after correction"), cex = cex)
+                 plot.PCA(memory, choix = 'ind', invisible = c('var', 'quali'), select = ind.names[extrem], title = gettext("Individuals factor map (PCA) before correction",domain="R-FactoInvestigate"), cex = cex)
+                 plot.PCA(res, choix = 'ind', invisible = c('var', 'quali'), select = drawn, title = gettext("Individuals factor map (PCA) after correction",domain="R-FactoInvestigate"), cex = cex)
                }
                
                writeRmd(file = file)
                writeRmd(file = file, start = TRUE, options = options, end = "")
                dump("drawn", file = file, append = TRUE)
                writeRmd("par(mar = c(4.1, 4.1, 1.1, 2.1))\nplot.PCA(memory, choix = 'ind', invisible = c('var', 'quali'), select = drawn, title = '', cex = cex)", file = file, stop = TRUE, end = "\n\n")
-               writeRmd("**", paste(figure.title, 1, sep = "."), " - ", gettext("Individuals factor map (PCA) before correction"), end = ".** \n", file = file, sep = "")
+               writeRmd("**", paste(figure.title, 1, sep = "."), " - ", gettext("Individuals factor map (PCA) before correction",domain="R-FactoInvestigate"), end = ".** \n", file = file, sep = "")
                if(length(extrem) == 1){
-                 writeRmd("*", gettext("Highlighting of an outlier"), end = ".* \n", file = file, sep = "")
+                 writeRmd("*", gettext("Highlighting of an outlier",domain="R-FactoInvestigate"), end = ".* \n", file = file, sep = "")
                } else {
-                 writeRmd("*", gettext("Highlighting of"), " ", length(extrem), " ", gettext("outliers"), end = ".* \n", file = file, sep = "")
+                 writeRmd("*", gettext("Highlighting of",domain="R-FactoInvestigate"), " ", length(extrem), " ", gettext("outliers",domain="R-FactoInvestigate"), end = ".* \n", file = file, sep = "")
                }
                
                
@@ -145,11 +145,11 @@ res.temp = res
                writeRmd(file = file, start = TRUE, options = options, end = "")
                dump("drawn", file = file, append = TRUE)
                writeRmd("par(mar = c(4.1, 4.1, 1.1, 2.1))\nplot.PCA(res, choix = 'ind', invisible = c('var', 'quali'), select = drawn, title = '', cex = cex)", file = file, stop = TRUE, end = "\n\n")
-               writeRmd("**", paste(figure.title, 2, sep = "."), " - ", gettext("Individuals factor map (PCA) after correction"), end = ".** \n", file = file, sep = "")
+               writeRmd("**", paste(figure.title, 2, sep = "."), " - ", gettext("Individuals factor map (PCA) after correction",domain="R-FactoInvestigate"), end = ".** \n", file = file, sep = "")
                if(length(extrem) == 1){
-                 writeRmd("*", gettext("Highlighting of an outlier"), end = ".* \n", file = file, sep = "")
+                 writeRmd("*", gettext("Highlighting of an outlier",domain="R-FactoInvestigate"), end = ".* \n", file = file, sep = "")
                } else {
-                 writeRmd("*", gettext("Highlighting of"), " ", length(extrem), " ", gettext("outliers"), end = ".* \n", file = file, sep = "")
+                 writeRmd("*", gettext("Highlighting of",domain="R-FactoInvestigate"), " ", length(extrem), " ", gettext("outliers",domain="R-FactoInvestigate"), end = ".* \n", file = file, sep = "")
                }
                
                selec.res = selection(res, dim = 1:2, margin = 2, selec = Vselec, coef = Vcoef)
@@ -157,17 +157,17 @@ res.temp = res
                what.drawn = selec.res[[2]]
                
                if(graph) {
-                 plot.PCA(memory, choix = 'var', select = drawn, title = gettext("Variables factor map (PCA) before correction"), cex = cex)
-                 plot.PCA(res, choix = 'var', select = drawn, title = gettext("Variables factor map (PCA) after correction"), cex = cex)
+                 plot.PCA(memory, choix = 'var', select = drawn, title = gettext("Variables factor map (PCA) before correction",domain="R-FactoInvestigate"), cex = cex)
+                 plot.PCA(res, choix = 'var', select = drawn, title = gettext("Variables factor map (PCA) after correction",domain="R-FactoInvestigate"), cex = cex)
                }
                
                writeRmd(file = file)
                writeRmd(file = file, start = TRUE, options = options, end = "")
                dump("drawn", file = file, append = TRUE)
                writeRmd("par(mar = c(4.1, 4.1, 1.1, 2.1))\nplot.PCA(memory, choix = 'var', select = drawn, title = '', cex = cex)", stop = TRUE, sep = "", file = file, end = "\n\n")
-               writeRmd("**", paste(figure.title, 3, sep = "."), " - ", gettext("Variables factor map (PCA) before correction"), "**", file = file, sep = "")
+               writeRmd("**", paste(figure.title, 3, sep = "."), " - ", gettext("Variables factor map (PCA) before correction",domain="R-FactoInvestigate"), "**", file = file, sep = "")
                if(!is.null(param$quali.sup)) {
-                 writeRmd("*", gettext("The variables in black are considered as active whereas those in blue are illustrative"), ".*", file = file, sep = "")
+                 writeRmd("*", gettext("The variables in black are considered as active whereas those in blue are illustrative",domain="R-FactoInvestigate"), ".*", file = file, sep = "")
                }
                writeRmd(what.drawn, file = file, sep = "")
                
@@ -175,7 +175,7 @@ res.temp = res
                writeRmd(file = file, start = TRUE, options = options, end = "")
                dump("drawn", file = file, append = TRUE)
                writeRmd("par(mar = c(4.1, 4.1, 1.1, 2.1))\nplot.PCA(res, choix = 'var', select = drawn, title = '', cex = cex)", stop = TRUE, sep = "", file = file, end = "\n\n")
-               writeRmd("**", paste(figure.title, 3, sep = "."), " - ", gettext("Variables factor map (PCA) after correction"), "**", file = file, sep = "")
+               writeRmd("**", paste(figure.title, 3, sep = "."), " - ", gettext("Variables factor map (PCA) after correction",domain="R-FactoInvestigate"), "**", file = file, sep = "")
                
                
                writeRmd("\n- - -", file = file, end = "\n\n")
@@ -199,32 +199,32 @@ res.temp = res
                }
                
                for(i in extrem){
-                 writeRmd("**", gettext("The individual"), " ", i, end = "** :\n\n", file = file, sep = "")
-                 writeRmd("-", gettext("takes very high values for the variable(s)"), end = " :\n", file = file)
+                 writeRmd("**", gettext("The individual",domain="R-FactoInvestigate"), " ", i, end = "** :\n\n", file = file, sep = "")
+                 writeRmd("-", gettext("takes very high values for the variable(s)",domain="R-FactoInvestigate"), end = " :\n", file = file)
                  liste.pos = names(which(sort(centred[rownames(data)[i],], decreasing = TRUE) > 2))
                  if(length(liste.pos) == 1) {
                    writeRmd("*", liste.pos, end = "*.\n\n", file = file, sep = "")
                  } else if(length(liste.pos) > 1 & length(liste.pos) < nmax) {
-                   writeRmd("*", paste(paste(liste.pos[- length(liste.pos)], collapse = "*, *"), liste.pos[length(liste.pos)], sep = gettext("* and *")), "* (", gettext("variables are sorted from the strongest"), end = ").\n\n", file = file, sep = "")
+                   writeRmd("*", paste(paste(liste.pos[- length(liste.pos)], collapse = "*, *"), liste.pos[length(liste.pos)], sep = gettext("* and *",domain="R-FactoInvestigate")), "* (", gettext("variables are sorted from the strongest",domain="R-FactoInvestigate"), end = ").\n\n", file = file, sep = "")
                  } else if(length(liste.pos) >= nmax) {
-                   writeRmd("*", paste(liste.pos[1:(nmax - 1)], collapse = "*, *"), gettext("* and *"), liste.pos[nmax], "* (", gettext("variables are sorted from the strongest"), end = ").\n\n", file = file, sep = "")
+                   writeRmd("*", paste(liste.pos[1:(nmax - 1)], collapse = "*, *"), gettext("* and *",domain="R-FactoInvestigate"), liste.pos[nmax], "* (", gettext("variables are sorted from the strongest",domain="R-FactoInvestigate"), end = ").\n\n", file = file, sep = "")
                  }
                  
-                 writeRmd("-", gettext("takes very low values for the variable(s)"), end = " :\n", file = file)
+                 writeRmd("-", gettext("takes very low values for the variable(s)",domain="R-FactoInvestigate"), end = " :\n", file = file)
                  liste.neg = names(which(sort(centred[rownames(data)[i],], decreasing = FALSE) < -2))
                  if(length(liste.neg) == 1) {
                    writeRmd("*", liste.neg, end = "*.\n\n", file = file, sep = "")
                  } else if(length(liste.neg) > 1 & length(liste.neg) < nmax) {
-                   writeRmd("*", paste(paste(liste.neg[- length(liste.neg)], collapse = "*, *"), liste.neg[length(liste.neg)], sep = gettext("* and *")), "* (", gettext("variables are sorted from the strongest"), end = ").\n\n", file = file, sep = "")
+                   writeRmd("*", paste(paste(liste.neg[- length(liste.neg)], collapse = "*, *"), liste.neg[length(liste.neg)], sep = gettext("* and *",domain="R-FactoInvestigate")), "* (", gettext("variables are sorted from the strongest",domain="R-FactoInvestigate"), end = ").\n\n", file = file, sep = "")
                  } else if(length(liste.neg) >= nmax) {
-                   writeRmd("*", paste(liste.neg[1:(nmax - 1)], collapse = "*, *"), gettext("* and *"), liste.neg[nmax], "* (", gettext("variables are sorted from the strongest"), end = ").\n\n", file = file, sep = "")
+                   writeRmd("*", paste(liste.neg[1:(nmax - 1)], collapse = "*, *"), gettext("* and *",domain="R-FactoInvestigate"), liste.neg[nmax], "* (", gettext("variables are sorted from the strongest",domain="R-FactoInvestigate"), end = ").\n\n", file = file, sep = "")
                  }
                }
                
                if(length(extrem) == 1) {
-                 writeRmd(gettext("This outlier is suppressed from the analysis and a second one is performed on the rest of the individuals"), end = ".\n", file = file)
+                 writeRmd(gettext("This outlier is suppressed from the analysis and a second one is performed on the rest of the individuals",domain="R-FactoInvestigate"), end = ".\n", file = file)
                } else {
-                 writeRmd(gettext("These outliers are suppressed from the analysis and a second one is performed on the rest of the individuals"), end = ".\n", file = file)
+                 writeRmd(gettext("These outliers are suppressed from the analysis and a second one is performed on the rest of the individuals",domain="R-FactoInvestigate"), end = ".\n", file = file)
                }
              },
              
@@ -232,30 +232,30 @@ res.temp = res
                res = MCA(param$data, quanti.sup = param$quanti.sup, quali.sup = param$quali.sup, ind.sup = ind.sup, graph = FALSE, row.w = row.w, ncp = param$ncp.mod)
                
                if(graph) {
-                 plot.MCA(memory, choix = 'ind', invisible = c('var', 'quali'), select = ind.names[extrem], title = gettext("Individuals factor map (MCA) before correction"), cex = cex)
-                 plot.MCA(res, choix = 'ind', invisible = c('var', 'quali'), select = drawn, title = gettext("Individuals factor map (MCA) after correction"), cex = cex)
+                 plot.MCA(memory, choix = 'ind', invisible = c('var', 'quali'), select = ind.names[extrem], title = gettext("Individuals factor map (MCA) before correction",domain="R-FactoInvestigate"), cex = cex)
+                 plot.MCA(res, choix = 'ind', invisible = c('var', 'quali'), select = drawn, title = gettext("Individuals factor map (MCA) after correction",domain="R-FactoInvestigate"), cex = cex)
                }
                
                writeRmd(file = file)
                writeRmd(file = file, start = TRUE, options = options, end = "")
                dump("drawn", file = file, append = TRUE)
                writeRmd("par(mar = c(4.1, 4.1, 1.1, 2.1))\nplot.MCA(memory, choix = 'ind', invisible = c('var', 'quali'), select = drawn, title = '', cex = cex)", file = file, stop = TRUE, end = "\n\n")
-               writeRmd("**", paste(figure.title, 1, sep = "."), " - ", gettext("Individuals factor map (MCA) before correction"), end = ".** \n", file = file, sep = "")
+               writeRmd("**", paste(figure.title, 1, sep = "."), " - ", gettext("Individuals factor map (MCA) before correction",domain="R-FactoInvestigate"), end = ".** \n", file = file, sep = "")
                if(length(extrem) == 1){
-                 writeRmd("*", gettext("Highlighting of an outlier"), end = ".* \n", file = file, sep = "")
+                 writeRmd("*", gettext("Highlighting of an outlier",domain="R-FactoInvestigate"), end = ".* \n", file = file, sep = "")
                } else {
-                 writeRmd("*", gettext("Highlighting of"), " ", length(extrem), " ", gettext("outliers"), end = ".* \n", file = file, sep = "")
+                 writeRmd("*", gettext("Highlighting of",domain="R-FactoInvestigate"), " ", length(extrem), " ", gettext("outliers",domain="R-FactoInvestigate"), end = ".* \n", file = file, sep = "")
                }
 
                writeRmd(file = file)
                writeRmd(file = file, start = TRUE, options = options, end = "")
                dump("drawn", file = file, append = TRUE)
                writeRmd("par(mar = c(4.1, 4.1, 1.1, 2.1))\nplot.MCA(res, choix = 'ind', invisible = c('var', 'quali'), select = drawn, title = '', cex = cex)", file = file, stop = TRUE, end = "\n\n")
-               writeRmd("**", paste(figure.title, 2, sep = "."), " - ", gettext("Individuals factor map (MCA) after correction"), end = ".** \n", file = file, sep = "")
+               writeRmd("**", paste(figure.title, 2, sep = "."), " - ", gettext("Individuals factor map (MCA) after correction",domain="R-FactoInvestigate"), end = ".** \n", file = file, sep = "")
                if(length(extrem) == 1){
-                 writeRmd("*", gettext("Highlighting of an outlier"), end = ".* \n", file = file, sep = "")
+                 writeRmd("*", gettext("Highlighting of an outlier",domain="R-FactoInvestigate"), end = ".* \n", file = file, sep = "")
                } else {
-                 writeRmd("*", gettext("Highlighting of"), " ", length(extrem), " ", gettext("outliers"), end = ".* \n", file = file, sep = "")
+                 writeRmd("*", gettext("Highlighting of",domain="R-FactoInvestigate"), " ", length(extrem), " ", gettext("outliers",domain="R-FactoInvestigate"), end = ".* \n", file = file, sep = "")
                }
                
                selec.res = selection(res, dim = 1:2, margin = 2, selec = Vselec, coef = Vcoef)
@@ -263,17 +263,17 @@ res.temp = res
                what.drawn = selec.res[[2]]
                
                if(graph) {
-                 plot.MCA(memory, choix = 'ind', invisible = 'ind', selectMod = drawn, title = gettext("Variables factor map (MCA) before correction"), cex = cex)
-                 plot.MCA(res, choix = 'ind', invisible = 'ind', selectMod = drawn, title = gettext("Variables factor map (MCA) after correction"), cex = cex)
+                 plot.MCA(memory, choix = 'ind', invisible = 'ind', selectMod = drawn, title = gettext("Variables factor map (MCA) before correction",domain="R-FactoInvestigate"), cex = cex)
+                 plot.MCA(res, choix = 'ind', invisible = 'ind', selectMod = drawn, title = gettext("Variables factor map (MCA) after correction",domain="R-FactoInvestigate"), cex = cex)
                }
                
                writeRmd(file = file)
                writeRmd(file = file, start = TRUE, options = options, end = "")
                dump("drawn", file = file, append = TRUE)
                writeRmd("par(mar = c(4.1, 4.1, 1.1, 2.1))\nplot.MCA(memory, choix = 'ind', invisible = 'ind', selectMod = drawn, title = '', cex = cex)", stop = TRUE, sep = "", file = file, end = "\n\n")
-               writeRmd("**", paste(figure.title, 3, sep = "."), " - ", gettext("Variables factor map (MCA) before correction"), "**", file = file, sep = "")
+               writeRmd("**", paste(figure.title, 3, sep = "."), " - ", gettext("Variables factor map (MCA) before correction",domain="R-FactoInvestigate"), "**", file = file, sep = "")
                if(!is.null(param$quali.sup)) {
-                 writeRmd("*", gettext("The factors in red are considered as active whereas those in green are illustrative"), ".*", file = file, sep = "")
+                 writeRmd("*", gettext("The factors in red are considered as active whereas those in green are illustrative",domain="R-FactoInvestigate"), ".*", file = file, sep = "")
                }
                writeRmd(what.drawn, file = file, sep = "")
                
@@ -281,7 +281,7 @@ res.temp = res
                writeRmd(file = file, start = TRUE, options = options, end = "")
                dump("drawn", file = file, append = TRUE)
                writeRmd("par(mar = c(4.1, 4.1, 1.1, 2.1))\nplot.MCA(res, choix = 'ind', invisible = 'ind', selectMod = drawn, title = '', cex = cex)", stop = TRUE, sep = "", file = file, end = "\n\n")
-               writeRmd("**", paste(figure.title, 3, sep = "."), " - ", gettext("Variables factor map (MCA) after correction"), "**", file = file, sep = "")
+               writeRmd("**", paste(figure.title, 3, sep = "."), " - ", gettext("Variables factor map (MCA) after correction",domain="R-FactoInvestigate"), "**", file = file, sep = "")
                
                
                writeRmd("\n- - -", file = file, end = "\n\n")
@@ -305,23 +305,23 @@ res.temp = res
                }
                
                for(i in extrem){
-                 writeRmd("**", gettext("The individual"), " ", i, end = "** :\n\n", file = file, sep = "")
+                 writeRmd("**", gettext("The individual",domain="R-FactoInvestigate"), " ", i, end = "** :\n\n", file = file, sep = "")
                  
-                 writeRmd("-", gettext("is characterized by the factor(s)"), end = " :\n", file = file)
+                 writeRmd("-", gettext("is characterized by the factor(s)",domain="R-FactoInvestigate"), end = " :\n", file = file)
                  liste.pos = names(which(sort(centred[rownames(data)[i],], decreasing = TRUE) > 2))
                  if(length(liste.pos) == 1) {
                    writeRmd("*", liste.pos, end = "*.\n\n", file = file, sep = "")
                  } else if(length(liste.pos) > 1 & length(liste.pos) < nmax) {
-                   writeRmd("*", paste(liste.pos, collapse = "*, *"), "* (", gettext("factors are sorted from the strongest"), end = ").\n\n", file = file, sep = "")
+                   writeRmd("*", paste(liste.pos, collapse = "*, *"), "* (", gettext("factors are sorted from the strongest",domain="R-FactoInvestigate"), end = ").\n\n", file = file, sep = "")
                  } else if(length(liste.pos) >= nmax) {
-                   writeRmd("*", paste(liste.pos[1:(nmax - 1)], collapse = "*, *"), gettext("* and *"), liste.pos[nmax], "* (", gettext("factors are sorted from the strongest"), end = ").\n\n", file = file, sep = "")
+                   writeRmd("*", paste(liste.pos[1:(nmax - 1)], collapse = "*, *"), gettext("* and *",domain="R-FactoInvestigate"), liste.pos[nmax], "* (", gettext("factors are sorted from the strongest",domain="R-FactoInvestigate"), end = ").\n\n", file = file, sep = "")
                  }
                }
                
                if(length(extrem) == 1) {
-                 writeRmd(gettext("This outlier is suppressed from the analysis and a second one is performed on the rest of the individuals"), end = ".\n", file = file)
+                 writeRmd(gettext("This outlier is suppressed from the analysis and a second one is performed on the rest of the individuals",domain="R-FactoInvestigate"), end = ".\n", file = file)
                } else {
-                 writeRmd(gettext("These outliers are suppressed from the analysis and a second one is performed on the rest of the individuals"), end = ".\n", file = file)
+                 writeRmd(gettext("These outliers are suppressed from the analysis and a second one is performed on the rest of the individuals",domain="R-FactoInvestigate"), end = ".\n", file = file)
                }
              },
              
@@ -338,7 +338,7 @@ res.temp = res
              HCPC = {})
       
     } else {
-      writeRmd(gettext("The analysis of the graphs does not detect any outlier"), file = file, end = ".\n")
+      writeRmd(gettext("The analysis of the graphs does not detect any outlier",domain="R-FactoInvestigate"), file = file, end = ".\n")
       res.out = res
       memory = NULL
     }
